Thanks for contributing to Scratchip! 🎉

### Is your proposal related to a problem?

<!--
  Provide a clear and concise description of what the problem is.
  For example, "I'm always frustrated when..."
-->

### Describe the solution you'd like

<!--
  Provide a clear and concise description of what you want to happen.
-->

### Describe alternatives you've considered

<!--
  Let us know about other solutions you've tried or researched.
-->

### Additional context

**Related issue**: <!-- if applicable -->

<!-- choose one -->
**Type of change**: bug report | feature request | documentation | other enhancement

<!-- choose one -->
**Impact**: no functional change | API addition (no impact on existing code) | API modification

<!-- choose one -->
**Development Phase**: proposal |  implementation
